@@ -75,14 +75,16 @@ class ColorPicker(Control):
         -------
         Button
         """
-        return cls(
+        tmp_cls = cls(
             cfg_dict["controlID"],
             cfg_dict["title"],
             _get_title_position(cfg_dict["titlePosition"]),
-            _get_color_picker_style(cfg_dict["titlePosition"]),
+            _get_color_picker_style(cfg_dict["pickerStyle"]),
             cfg_dict["sendOnlyOnRelease"],
             ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"])
         )
+        tmp_cls.parent_id = cfg_dict["parentID"]
+        return tmp_cls
 
 
     def get_state(self):
